---
title: <span class="badge object-type-scalar"></span> CubicFeetPerMinute
---
# <span class="badge object-type-scalar"></span> CubicFeetPerMinute

Flow: Cubic feet/min (cfm)

## Definition

```python
# Flow: Cubic feet/min (cfm)
CubicFeetPerMinute: typing.Literal["flowcms"] = "flowcms"
```
